Class: Beagle::Turso::Database
- Inherits:
-
Object
- Object
- Beagle::Turso::Database
- Defined in:
- lib/beagle/turso.rb
Class Method Summary collapse
-
.open(local_path:, remote_url: nil, auth_token: nil, bootstrap_if_empty: true) ⇒ Object
Opens a local-only database, or one synced with a remote Turso database when both
remote_urlandauth_tokenare given (see#push/#pull).
Class Method Details
.open(local_path:, remote_url: nil, auth_token: nil, bootstrap_if_empty: true) ⇒ Object
Opens a local-only database, or one synced with a remote Turso
database when both remote_url and auth_token are given (see
#push/#pull). Delegates to the native _open primitive, which
takes its arguments positionally.
20 21 22 |
# File 'lib/beagle/turso.rb', line 20 def self.open(local_path:, remote_url: nil, auth_token: nil, bootstrap_if_empty: true) _open(local_path, remote_url, auth_token, bootstrap_if_empty) end |